import random
import sys
import os
import time
from datetime import datetime

def computeKey(typ, subTyp):
	return str(typ)+"-"+str(subTyp)

def createHeader(tId, typ, subTyp, ssc, length):
	firstbyte = tId;
	seconbyte = subTyp + typ*16;
	sscBytes = ssc.to_bytes(2,'big')
	lengthBytes = length.to_bytes(2,'big')
	return bytes([firstbyte,seconbyte])+sscBytes+lengthBytes

def createPacket(tId, typ, subTyp, ssc, length):
	header = createHeader(tId, typ, subTyp, ssc, length);
	data = bytes(int(str(random.randint(0,255)),0) for x in range(0,length+1))
	return header+data

def createGoToIdlePacket(ssc, tId, length):
	header = createHeader(tId, 15, 1, ssc, length);
	spare = 0
	cmd = 21845
	data = spare.to_bytes(2,'big') + cmd.to_bytes(2,'big')
	return header+data

def createGoToRunPacket(ssc, tId, length):
	header = createHeader(tId, 15, 1, ssc, length);
	spare = 0
	cmd = 43690
	data = spare.to_bytes(2,'big') + cmd.to_bytes(2,'big')
	return header+data

def getNextSsc(ssc,perLost):
	newlost = 0
	if ssc == 65535:
		newssc = 0
	else:
		newssc = ssc+1
	#newssc = 1*(ssc==65535)+(ssc+1)*(ssc!=65535)
	while(random.randint(0,100) < perLost):
		if newssc == 65535:
			newssc = 0
		else:
			newssc = newssc+1
		newlost +=1
	return newssc, newlost

def main():
	if ((len(sys.argv) > 0) and (len(sys.argv) != 11)):
		print("Utilizzo: [mb|packs] [MBsize|num packet] [%lost] [°/ooo switch] [%calib] [TelesID] [type] [subType] [NOPERIODIC|YESPERIODIC] [RUN|IDLE]")
		print("[mb|packs]:\n\tscegliere se fermare la produzione dei pacchetti al raggiungimento di un valore di MegaByte prodotti oppure di numero di pacchetti prodotti")
		print("[MBsize|num packet]:\n\tvalore di soglia in base al parametro precedente;")
		print("%Lost:\n\tpercentuale di pacchetti persi;")
		print("°/ooo switch:\n\t°/ooo pacchetti cmd (go to run, go to idle);")
		print("%calib:\n\t percentuale di run di calibrazione rispetto alle scientifiche;")
		print("TelesID:\n\tsorgente dati; inserire valore intero oppure \"random\" e verrà scelto un valore casuale [1:10] per ogni pacchetto;")
		print("Type:\n\ttipo del pacchetto, valore intero oppure \"random\" e verrà scelto un valore casuale [1,2 o 10] per ogni pacchetto;")
		print("SubType:\n\tsottotipo del pacchetto, valore intero oppure \"random\" e verrà scelto un valore casuale (tra quelli possibili per il type);")
		print("[NOPERIODIC|YESPERIODIC]:\n\tdefinisci se inserire anche pacchetti periodici (hk e var) nelle run di calibrazione o scientifiche;")
		print("[RUN|IDLE]:\n\tDefinisci con quale stato iniziare;")
		print("Esempi:")
		print("\tpython ./PacketFactory.py mb 5000 5 10 30 7 random random NOPERIODIC RUN")
		print("\tpython ./PacketFactory.py packs 1000 5 50 10 random 2 2 YESPERIODIC IDLE")
		print("\tpython ./PacketFactory.py packs 1000 0 0 0 7 2 2 NOPERIODIC RUN")
		print("\t\tIl precedente esempio genera un file con solo pacchetti tipo 2-2 e con TelesID fisso a 7")
		print("\tpython ./packetFactory.py mb 200 0 15 50 7 random random YESPERIODIC IDLE")
		print("\t\tIl precedente esempio genera un file \"realistico\" con run scientiche alternate a run di calibrazione e fasi di idle")
		exit()

## ELAB INPUT PARAMS ###################################
	stop = sys.argv[1]
	limit = float(sys.argv[2])
	perLost = int(sys.argv[3])
	perSwitchState = int(sys.argv[4])
	perCalib = int(sys.argv[5])
	tId = sys.argv[6]
	if(tId != "random"):
		tId = int(tId)
	typ = sys.argv[7]
	if(typ != "random"):
		typ = int(typ)
	subTyp = sys.argv[8]
	if(subTyp != "random"):
		subTyp = int(subTyp)
	periodicFlag = sys.argv[9]
	if(periodicFlag == "NOPERIODIC"):
		periodicFlag = False
		periodicStr = "NO"
	else:
		periodicFlag = True
		periodicStr = "YES"
	state = sys.argv[10]
	if(state == "IDLE"):
		state = 0
		stateStr = "IDLE"
	else:
		state = 1
		stateStr = "RUN"
	calibFlag = True # Parte con la calibrazione
	print("Starting with:")
	print("Limit: {}, Size: {}, %lost: {}, °/ooo switch: {}, %calib: {}, TelesID: {}, Type: {}, SubType: {}, Periodics: {}, State: {}".format(stop,limit,perLost,perSwitchState,perCalib,tId,typ,subTyp,periodicStr,stateStr))
	if(stop == "mb"):
		limit = limit*10**6 # -> MB -> Byte
###########################################################	


	#### Pacchetti supportati
	typeList = [1,2,10,15]
	calibType = 1
	scientType = 2
	periodicType = 10
	commandType = 15
	subtypeDictionary = {1:[1,4], 2:[2], 10:[1,2,3], 15:[1]} #sottotipi supportati per ogni tipo
	lengths = {"1-1":10014-7, "1-4":12980-7, "2-2":12976-7, "10-1":11098-7, "10-2":9566-7, "10-3":9566-7, "15-1":10-7} # Lunghezze (packetLength nell'header)
	ssc = {"1-1":-1, "1-4":-1, "2-2":-1, "10-1":-1, "10-2":-1, "10-3":-1, "15-1":-1} # ssc iniziali
	headerSize = 6


	#### Parametri globali per statistiche 
	totByte = 0
	numPack = 0
	lost = 0
	numRun = 0
	numIdle = 0
	if state == 0:
		numIdle += 1
	else:
		numRun +=1
	crc = 1

## PREPARE OUTPUT FILE #################################
	now = datetime.now()
	current_time = now.strftime("%H-%M-%S-%f")
	fileName = current_time+".raw"
	start = time.perf_counter() # Start timer
########################################################

	calibSubType = 1 # Setta la prima calibrazione al subtype 1
	with open(fileName,'wb') as f:

		while( (numPack<limit)*(stop == "packs") + (totByte<limit)*(stop == "mb") ): # CONDIZIONE DI STOP (numero di pacchetti o dimensione file)
		
		#### Switch state e va in idle o in run ########################
			if random.randint(0,10000) < perSwitchState:
				entry = computeKey(15,1)
				ssc[entry], new_lost = getNextSsc(ssc[entry],perLost)
				aTID = random.randint(1,7) if tId == "random" else tId
				aLenght = lengths[entry]
				if random.randint(0,100) > 50: # Go to idle
					pkt = createGoToIdlePacket(ssc[entry],aTID, aLenght)
					numIdle += 1
					state = 0
				else:				# Go to Run
					pkt = createGoToRunPacket(ssc[entry],aTID, aLenght)
					numRun += 1
					state = 1
					if random.randint(0,100) < perCalib: # Calibration run
						calibFlag = True
						calibSubType = random.choice(subtypeDictionary[calibType]) # Sceglie randomicamente tipo di calibrazione
					else:
						calibFlag = False # Scientific Run
				# Scrive il Notif packet
				f.write(bytes(int(str(byte),0) for byte in pkt))
				lost += new_lost
				totByte += headerSize + aLenght+1
				numPack+=1
		################################################################
			

		#### STATO DI IDLE #############################################
			if state == 0: # manda solo hk e var (1/3 possibilità ognuno)
				aTyp = periodicType
				aSubTyp = random.choice(subtypeDictionary[aTyp]) 
		################################################################

		#### STATO DI RUN ###############################################
			else: # setta il pacchetto secondo le impostazioni
				if typ == "random":
					aTypeList = typeList.copy()
					aTypeList.remove(commandType) # rimuove i tipi command dalla possibile scelta
					if not periodicFlag: # rimuove i tipi periodici dalla possibile scelta
						aTypeList.remove(periodicType)
					if not calibFlag: # rimuove i tipi calibrazione o scientifico dalla possibile scelta
						aTypeList.remove(calibType)
					else:
						aTypeList.remove(scientType)
					aTyp = random.choice(aTypeList) # effettua la scelta random tra i tipi rimasti
				else:
					aTyp = typ

				if aTyp == calibType and subTyp == "random": # Se è calibrazione allora il subtype è quello deciso nello switch state
					aSubTyp = calibSubType
				else:
					if subTyp == "random":
						aSubTyp = random.choice(subtypeDictionary[aTyp])
					else:
						aSubTyp = subTyp

		##################################################################

		### Scrive il pacchetto appena costruito #########################
			entry = computeKey(aTyp,aSubTyp)
			ssc[entry], new_lost = getNextSsc(ssc[entry],perLost)
			aTID = random.randint(1,7) if tId == "random" else tId
			aLenght = lengths[entry]
			pkt = createPacket(aTID,aTyp,aSubTyp,ssc[entry],aLenght);
			f.write(bytes(int(str(byte),0) for byte in pkt))
			lost += new_lost
			totByte += headerSize + aLenght+1
			numPack+=1
		##################################################################


	##### PREPARA IL NOME DEFINITIVO DEL FILE DI OUTPUT ##################		
	aTyp = "rnd" if typ == "random" else typ
	aSub = "rnd" if subTyp == "random" else subTyp
	aTID = "rnd" if tId == "random" else tId
	finalMBsize = totByte/10**6
	newFileName = "pack[{}_{}]-{}MB-{}n-{}Los-{}TID-{}Run-{}Idle.raw".format(aTyp,aSub,round(finalMBsize,2),numPack,lost,aTID,numRun,numIdle)
	os.rename("./"+fileName,newFileName)
	######################################################################		

	##### STAMPA TEMPO TRASCORSO ##############################
	end = time.perf_counter()
	elps = end - start
	if elps > 60:
		print("time elapsed: " + str((elps)/60) + " minutes")
	else:
		print("time elapsed: " + str(elps) + " seconds")


if __name__ == '__main__':
	main()
