
#DAQ CONFIG
CREATE TABLE `BIAS`.`astridaq_config` (
  `id` int NOT NULL AUTO_INCREMENT,
  `receiver` varchar(255) NOT NULL DEFAULT 'tcp',
  `archiver` varchar(255) NOT NULL DEFAULT 'file',
  `provider` varchar(255) NOT NULL DEFAULT 'redis',
  `packet` varchar(255) NOT NULL DEFAULT 'astrima',
  `monitor` varchar(255) NOT NULL DEFAULT 'astrisimple',
  `daq_id` int DEFAULT '0',
  `active` bool NOT NULL DEFAULT FALSE ,
  PRIMARY KEY (`id`)
);
INSERT INTO `BIAS`.`astridaq_config` VALUES (DEFAULT,DEFAULT,DEFAULT,DEFAULT,DEFAULT,DEFAULT,DEFAULT,TRUE);

CREATE TABLE `BIAS`.`schedulingblock_config` (
  `id` int NOT NULL AUTO_INCREMENT,
  `date` varchar(8) DEFAULT '19700101',
  `target_id` varchar(50) DEFAULT 'CrabNebula',
  `obs_mode` varchar(10) DEFAULT 'ON',
  `tel_id` int DEFAULT '7',
  `run_id` int DEFAULT '11',
  `active` bool DEFAULT FALSE,
  PRIMARY KEY (`id`)
);
INSERT INTO `BIAS`.`schedulingblock_config` VALUES (DEFAULT,DEFAULT,DEFAULT,DEFAULT,DEFAULT,DEFAULT,TRUE);

CREATE TABLE `BIAS`.`tcpreceiver_config` (
  `id` int NOT NULL AUTO_INCREMENT,
  `ip` varchar(255) NOT NULL DEFAULT '127.0.0.1',
  `port` int NOT NULL DEFAULT 9003,
  `active` bool DEFAULT FALSE,
  PRIMARY KEY (`id`)
);
INSERT INTO `BIAS`.`tcpreceiver_config` VALUES (DEFAULT,DEFAULT,DEFAULT,TRUE);

CREATE TABLE `BIAS`.`udpreceiver_config` (
  `id` int NOT NULL AUTO_INCREMENT,
  `ip` varchar(255) NOT NULL DEFAULT '127.0.0.1',
  `port` int NOT NULL DEFAULT 9003,
  `active` bool DEFAULT FALSE,
  PRIMARY KEY (`id`)
);
INSERT INTO `BIAS`.`udpreceiver_config` VALUES (DEFAULT,DEFAULT,DEFAULT,TRUE);

CREATE TABLE `BIAS`.`filearchiver_config` (
  `id` int NOT NULL AUTO_INCREMENT,
  `file_name` varchar(255) NOT NULL DEFAULT 'tmp',
  `archive_path` varchar(255) NOT NULL DEFAULT '$BIAS_PREFIX/ArchiveRAW',
  `active` bool DEFAULT FALSE,
  PRIMARY KEY (`id`)
);
INSERT INTO `BIAS`.`filearchiver_config` VALUES (DEFAULT,DEFAULT,DEFAULT,TRUE);


CREATE TABLE `BIAS`.`kafkaprovider_config` (
  `id` int NOT NULL AUTO_INCREMENT,
  `ip` varchar(255) NOT NULL DEFAULT '127.0.0.1',
  `port` int NOT NULL DEFAULT 9092,
  `topic` varchar(255) NOT NULL DEFAULT 'Astri_ADAS_topic',
  `active` bool DEFAULT FALSE,
  PRIMARY KEY (`id`)
);
INSERT INTO `BIAS`.`kafkaprovider_config` VALUES (DEFAULT,DEFAULT,DEFAULT,DEFAULT,TRUE);

CREATE TABLE `BIAS`.`redisprovider_config` (
  `id` int NOT NULL AUTO_INCREMENT,
  `ip` varchar(255) NOT NULL DEFAULT '127.0.0.1',
  `port` int NOT NULL DEFAULT 6379,
  `key` varchar(255) NOT NULL DEFAULT 'Astri_ADAS_key',
  `active` bool DEFAULT FALSE,
  PRIMARY KEY (`id`)
);
INSERT INTO `BIAS`.`redisprovider_config` VALUES (DEFAULT,DEFAULT,DEFAULT,DEFAULT,TRUE);

CREATE TABLE `BIAS`.`astrisimplemonitor_config` (
  `id` int NOT NULL AUTO_INCREMENT,
  `rateinterval` int NOT NULL DEFAULT 10,
  `active` bool DEFAULT FALSE,
  PRIMARY KEY (`id`)
);
INSERT INTO `BIAS`.`astrisimplemonitor_config` VALUES (DEFAULT,DEFAULT,TRUE);

CREATE TABLE `BIAS`.`acquired_files` (
  `id` int NOT NULL AUTO_INCREMENT,
  `folder` varchar(255) NOT NULL,
  `name` varchar(255) NOT NULL,
  `daq_id` int NOT NULL,
  `created_at` timestamp NOT NULL,
  `closed_at` timestamp,
  `sent` int NOT NULL DEFAULT 0,
  `scheduling_block_id` int, 
  CONSTRAINT `FK_scheduling_block_id`
  FOREIGN KEY (`scheduling_block_id`)
  REFERENCES `schedulingblock_config` (`id`),
  PRIMARY KEY (`id`)
);

# PROCESSOR CONFIG
CREATE TABLE `BIAS`.`astriprocessor_config` (
  `id` int NOT NULL AUTO_INCREMENT,
  `receiver` varchar(255) NOT NULL DEFAULT 'redis',
  `provider` varchar(255) NOT NULL DEFAULT 'kafkaavro',
  `packet` varchar(255) NOT NULL DEFAULT 'astrima',
  `toprocess` varchar(255) NOT NULL DEFAULT '11_14_22_101_102_103',
  `connectionTimeout` int NOT NULL DEFAULT -1,
  `closingTimeout` int NOT NULL DEFAULT 10,
  `active` bool NOT NULL DEFAULT FALSE ,
  PRIMARY KEY (`id`)
);
INSERT INTO `BIAS`.`astriprocessor_config` VALUES (DEFAULT,DEFAULT,DEFAULT,DEFAULT,DEFAULT,DEFAULT,DEFAULT,TRUE);

CREATE TABLE `BIAS`.`redisreceiver_config` (
  `id` int NOT NULL AUTO_INCREMENT,
  `ip` varchar(255) NOT NULL DEFAULT '127.0.0.1',
  `port` int NOT NULL DEFAULT 6379,
  `key` varchar(255) NOT NULL DEFAULT 'Astri_ADAS_key',
  `checkinterval` int NOT NULL DEFAULT 1,
  `active` bool DEFAULT FALSE,
  PRIMARY KEY (`id`)
);
INSERT INTO `BIAS`.`redisreceiver_config` VALUES (DEFAULT,DEFAULT,DEFAULT,DEFAULT,DEFAULT,TRUE);

CREATE TABLE `BIAS`.`filereceiver_config` (
  `id` int NOT NULL AUTO_INCREMENT,
  `source` varchar(255) NOT NULL DEFAULT '$BIAS_PREFIX/config/RawTestFiles',
  `rate` int NOT NULL DEFAULT 10,
  `active` bool DEFAULT FALSE,
  PRIMARY KEY (`id`)
);
INSERT INTO `BIAS`.`filereceiver_config` VALUES (DEFAULT,DEFAULT,DEFAULT,TRUE);

CREATE TABLE `BIAS`.`kafkaavroprovider_config` (
  `id` int NOT NULL AUTO_INCREMENT,
  `ip` varchar(255) NOT NULL DEFAULT '127.0.0.1',
  `port` int NOT NULL DEFAULT 9092,
  `topic` varchar(255) NOT NULL DEFAULT 'Astri_ADAS_avro_topic',
  `active` bool DEFAULT FALSE,
  PRIMARY KEY (`id`)
);
INSERT INTO `BIAS`.`kafkaavroprovider_config` VALUES (DEFAULT,DEFAULT,DEFAULT,DEFAULT,TRUE);


#STORAGE CONF
CREATE TABLE `BIAS`.`archiving_config` (
  `id` int NOT NULL AUTO_INCREMENT,
  `host` varchar(255),
  `username` varchar(255),
  `password` varchar(255),
  `remote_path` varchar(255),
  `port` varchar(255),
  `connection` varchar(255),
  `active` bool DEFAULT FALSE,
  PRIMARY KEY (`id`)
);
